#
# spec file for package robinhood
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%define installdir_www %{_localstatedir}/lib/
%define githash 1ca39f131bb35f120f458faf4e70779d5621e8cd

Name:           robinhood
Version:        3.1.7
Release:        bp160.1.7
Summary:        Policy engine and reporting tool for large filesystems
License:        CECILL-C
Group:          System/Monitoring
URL:            https://github.com/cea-hpc/robinhood
Source0:        https://github.com/cea-hpc/robinhood/archive/%{githash}.tar.gz#/%{name}-%{version}.tar.gz
Patch1:         web-gui.patch
Patch2:         rbh-config.patch
Patch3:         avoid-version.patch
Patch4:         make-test_confparam-depend-on-lustre.patch
Patch5:         harden_robinhood.service.patch
Patch6:         harden_robinhood@.service.patch
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  glib2-devel
BuildRequires:  glibc-devel
BuildRequires:  jemalloc-devel
BuildRequires:  libmysqlclient-devel
BuildRequires:  libtool
BuildRequires:  mailx
BuildRequires:  systemd-rpm-macros
BuildRequires:  zlib-devel
Requires:       which
Recommends:     mysql-server
Recommends:     mysql-server-devel
Provides:       robinhood = %{version}-%{release}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}
Requires(post): %fillup_prereq
ExcludeArch:    i586

%description
The Robinhood Policy Engine is a tool to manage contents of large
file systems. It maintains a replicate of filesystem medatada in a
database that can be queried at will. It makes it possible to
schedule mass action on filesystem entries by defining
attribute-based policies, provides fast 'find' and 'du' enhanced
clones, gives to administrators an overall view of filesystem
contents through its web UI and command line tools.

It supports any POSIX filesystem and implements advanced features for
Lustre filesystems (list/purge files per OST or pool, read MDT
changelogs...)

%package webgui
Summary:        Web interface to vizualize filesystems stats
Group:          System/Monitoring
Requires:       apache2
Requires:       php
Requires:       php-mysql
Requires:       php-pdo
BuildRequires:  apache2
Requires:       mod_php_any

%description webgui
Web interface to vizualize filesystems stats. This uses robinhood database
to display miscelancous user and group stats.

%package tools
Summary:        Tools for accessing the statistics
Group:          System/Monitoring

%description tools
The commanline tools for extracting the information out of the
robinhood database. Commands work like du or df and find. Be careful
as robinhood_find does not always honor the file permissions.

%package tests
Summary:        Internal tests for robinhood
Group:          System/Monitoring

%description tests
Tests and examples for the robinhood policy engine.

%prep
%setup -q -n %{name}-%{githash}
%patch -P 1
# the macro {installdir_www} is not known in the patch
sed -i 's,WWWROOT,%{installdir_www}robinhood,g' web_gui/robinhood.conf
%patch -P 2
%patch -P 3
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
# remove spurious executeable bits
find ./doc/templates -type f -executable -exec chmod 644 {} +

# manual call for autobuild
autoreconf -fi

%build
export CFLAGS="%optflags -Wno-error=unused-result"
%configure \
  --enable-lustre \
  --disable-static \
  --enable-dependency-tracking \
  %{nil}
make %{?_smp_mflags}

%install
%make_install
# remove static linking for libraries
find %{buildroot} -regex '.*\.[la]*' -print -delete
# move architecture dependend test file library location to trick rpmlint
mv %{buildroot}%{_datadir}/robinhood/tests/create-random %{buildroot}%{_libdir}/robinhood/
ln -s %{_libdir}/robinhood/create-random %{buildroot}%{_datadir}/robinhood/tests/create-random
# get the web config
mkdir -p %{buildroot}/%{installdir_www}/robinhood
mkdir -p %{buildroot}/%{_sysconfdir}/apache2/conf.d/
cp -r web_gui/gui_v3/* %{buildroot}/%{installdir_www}/robinhood/.
#fix executeable bits
chmod 0644  %{buildroot}/%{installdir_www}/robinhood/js/*.js
cp    web_gui/gui_v3/api/.htaccess %{buildroot}/%{installdir_www}/robinhood/api/.
install -m 644 web_gui/robinhood.conf %{buildroot}/%{_sysconfdir}/apache2/conf.d/.
# install systemd
mkdir -p  %{buildroot}/%{_unitdir}
install -m 644 scripts/robinhood.service %{buildroot}/%{_unitdir}/robinhood.service
install -m 644 scripts/robinhood@.service %{buildroot}/%{_unitdir}/robinhood@.service
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcrobinhood
mkdir -p %{buildroot}/%{_fillupdir}/
install -m 644 scripts/sysconfig_robinhood %{buildroot}/%{_fillupdir}/sysconfig.%{name}
# remove duplicates in tests
%fdupes -s  %{buildroot}/%{_datadir}/robinhood/tests
# Ugly fix to add right shebang line
for file in $(find %{buildroot}%{_datadir}/robinhood/tests/ -name \*.sh) ; do grep '#!/bin/bash' $file || sed -i '1s,^,#!/bin/bash\n,' $file ;done
# created config dir
mkdir -p %{buildroot}/%{_sysconfdir}/robinhood.d/

#service files for systemd
%pre
%service_add_pre robinhood.service robinhood@.service

%post
%{fillup_only}
%service_add_post robinhood.service robinhood@.service

%preun
%service_del_preun robinhood.service robinhood@.service

%postun
%service_del_postun robinhood.service robinhood@.service

%files
%defattr(-,root,root)
%license LICENSE.en.txt LICENSE.fr.txt
%doc ChangeLog README.md
%doc ./doc/templates/

%{_mandir}/man1/robinhood*

%{_sbindir}/rbh-undelete
%{_sbindir}/rbh_cksum.sh
%{_sbindir}/rbh-config
%{_sbindir}/rbh-rebind
%{_sbindir}/robinhood
%{_sbindir}/rcrobinhood

%dir %{_libdir}/robinhood
%{_libdir}/robinhood/librbh_mod_*.so*

%{_unitdir}/robinhood.service
%{_unitdir}/robinhood@.service
%{_fillupdir}/sysconfig.%{name}

%dir %{_sysconfdir}/robinhood.d/

%files tools
%{_bindir}/rbh-du
%{_bindir}/rbh-find
%{_sbindir}/rbh-report
%{_sbindir}/rbh-diff
%{_mandir}/man1/rbh-*

%dir %{_sysconfdir}/robinhood.d/

%files webgui
%defattr(-,wwwrun,www)
%{installdir_www}/robinhood
%config(noreplace) %{_sysconfdir}/apache2/conf.d/robinhood.conf
%config(noreplace) %{installdir_www}/robinhood/config.php
%attr(640,-,-) %{installdir_www}/robinhood/config.php

%files tests
%defattr(-,root,root,-)
%{_datadir}/robinhood/tests/
%{_libdir}/robinhood/create-random
%dir %{_datadir}/robinhood

%changelog
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Apr 12 2023 Christian Goll <cgoll@suse.com>
- removed errors on warnings from gcc12
* Mon Nov 22 2021 Christian Goll <cgoll@suse.com>
- update to 3.1.7 with following minor fixes:
  * fix optimization for policy runs per OST
  * fix pool_usage trigger
  * fix pool parsing
* Mon Nov 15 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_robinhood.service.patch
  * harden_robinhood@.service.patch
* Fri Oct 23 2020 Christian Goll <cgoll@suse.com>
- fixed license files
* Tue Oct 20 2020 Christian Goll <cgoll@suse.com>
- update to version 3.1.6 with following changes:
  * fix build on Lustre 2.12.4
  * check the filesystem returns consistent statfs values
  * chglog_reader: reopen changelog in case of unexpected error
  * chglog_reader: de-duplicate HSM STATE events (keep the latest)
  * policy run time stat now includes initial DB request time
  * fix the use of archive_id parameter in lhsm
- fixed build on newer autoconf versions
  * added file make-test_confparam-depend-on-lustre.patch
* Mon Dec 16 2019 Christian Goll <cgoll@suse.com>
- added zlib-devel as BuildRequires, as openSUSE Leap 15.2 does
  not have them per default in the build environment.
* Thu Sep 12 2019 Christian Goll <cgoll@suse.com>
- removed i586 builds
* Mon Sep  2 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- New version 3.1.5, please read ChangeLog for changes.
- Update Source0 to use GitHub insterad of sourceforge.
- New BuildRequires on jemalloc-devel
- New binary rbh-rebind
- Use %%license
- Patches removed, merged upstream:
  * xattr-location.patch
  * removed-check-ENOATTR.patch
* Tue Oct 23 2018 cgoll@suse.com
-  moved packages tools webgui and tests from Applications/System
  to System/Monitoring
* Wed Sep 12 2018 cgoll@suse.com
- removed dependency on libattr-devel as xattr.h is now part
  of glibc-devel
- added patch xattr-location.patch which chnages the include from
  attr/xattr.h to sys/xattr.h
- added patch removed-check-ENOATTR.patch which removes check for
  error ENOATTR which is a cpoy of allreay checked error
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Oct 18 2017 cgoll@suse.com
- Changed robinhood-webgui path and fixed php version
* Thu Oct 12 2017 jengelh@inai.de
- Update package descriptions.
* Wed Oct 11 2017 cgoll@suse.com
- updated to robinhood-3.1
- fixed devel-file-in-non-devel-package via patch avoid-version.patch
- moved binary used for tests to _libdir and pointed a softlink to it
  at its original position
* Wed Aug 16 2017 eich@suse.com
- Replaced some hard coded directories.
* Wed Aug 16 2017 cgoll@suse.com
- rbh-config.patch: removed rbh_config call, as it is only needed for sql
  version
- static-link.patch: made tests static linked as they wont complie otherwise
- web-gui.patch: removed virtual apache server
- initial commit for 323855 and made tests static linked
